# log12

Log12 unifies metrics, distributed tracing and text-based event logging in a single and self-contained structured logging library that follows the [12-factor logging recommendation](https://12factor.net/logs) consequently.